@@ -2,32 +2,26 @@
 # -*- coding: utf-8 -*-
 #
 # ***** BEGIN LICENSE BLOCK *****
-# Copyright (C) 2012-2014, Hayaki Saito 
+# Copyright (C) 2012-2014  Hayaki Saito <user@zuse.jp>
 # 
-# Permission is hereby granted, free of charge, to any person obtaining a 
-# copy of this software and associated documentation files (the "Software"), 
-# to deal in the Software without restriction, including without limitation 
-# the rights to use, copy, modify, merge, publish, distribute, sublicense, 
-# and/or sell copies of the Software, and to permit persons to whom the 
-# Software is furnished to do so, subject to the following conditions: 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 # 
-# The above copyright notice and this permission notice shall be included in 
-# all copies or substantial portions of the Software. 
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL 
-# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
-# DEALINGS IN THE SOFTWARE. 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 # 
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
 __author__  = "Hayaki Saito (user@zuse.jp)"
-__version__ = "0.2.8"
+__version__ = "0.2.9"
 __license__ = "MIT"
-signature   = '606d2e0c303b456d741e1359940f7a4f'
+signature   = '272bd51a6856e85ac4032a83b35779a6'
 
 import sys
 import os
@@ -145,9 +139,12 @@ class Scanner:
     def __iter__(self):
         raise NotImplementedError("Scanner::__iter__")
 
+    # deprecated
     def assign(self, value, termenc):
         raise NotImplementedError("Scanner::assign")
 
+    def continuous_assign(self, value, termenc):
+        raise NotImplementedError("Scanner::continuous_assign")
 
 class OutputStream:
     ''' abstruct TTY output stream '''
@@ -586,17 +583,23 @@ class DefaultParser(Parser):
 #
 class DefaultScanner(Scanner):
     ''' scan input stream and iterate UCS code points '''
-    _data = None
-    _ucs4 = True
 
-    def __init__(self, ucs4=True):
+    def __init__(self, ucs4=True, termenc=None):
         """
         >>> scanner = DefaultScanner()
         >>> scanner._ucs4
         True
         """
+        self._data = None
         self._ucs4 = ucs4
+        if termenc:
+            self._decoder = codecs.getincrementaldecoder(termenc)(errors='replace')
+            self._termenc = termenc
+        else:
+            self._decoder = None
+            self._termenc = None
 
+    # deprecated
     def assign(self, value, termenc):
         """
         >>> scanner = DefaultScanner()
@@ -604,7 +607,19 @@ class DefaultScanner(Scanner):
         >>> scanner._data
         u'01234'
         """
-        self._data = unicode(value, termenc, 'ignore')
+        if self._termenc != termenc:
+            self._decoder = codecs.getincrementaldecoder(termenc)(errors='replace')
+            self._termenc = termenc
+        self._data = self._decoder.decode(value)
+
+    def continuous_assign(self, value):
+        """
+        >>> scanner = DefaultScanner(termenc="utf-8")
+        >>> scanner.continuous_assign("01234")
+        >>> scanner._data
+        u'01234'
+        """
+        self._data = self._decoder.decode(value)
 
     def __iter__(self):
         """
